@@ -1,7 +1,11 @@
 use sysinfo::{System, SystemExt};
 
 use crate::utils::{process_info::*, request::build_reqwest_client};
-use crate::RESTClient;
+
+pub struct RESTClient {
+    port: u32,
+    reqwest_client: reqwest::Client,
+}
 
 type Error = Box<dyn std::error::Error>;
 
@@ -12,8 +16,8 @@ impl RESTClient {
         sys.refresh_all();
         let process = find_process(&sys)?;
         let args = extract_info(process)?;
-        let rest_token = encode_token(&args.0);
-        let client = build_reqwest_client(Some(rest_token))?;
+        let auth_token = encode_token(&args.0);
+        let client = build_reqwest_client(Some(auth_token))?;
         Ok(Self {
             port: args.1,
             reqwest_client: client,
